function TooManyOrFewInlineInputs

DoubleX = inline('2*x','x');

% SixEight = feval(DoubleX, 3, 4) % Comment this line to see the error on line 5
% Empty = feval(DoubleX) % Comment this line to see the error on line 12

% We will try to solve the ODE x'= -k*x with x(0) = 2, k = 0.5
k = 0.5;
x0 = 2;
ODEFun = inline('-k*x', 't', 'x', 'k');
[t,y] = ode45(ODEFun, [0 5],  x0, [], k);

y1=2*exp(-k*t);
[t y y1]

% Possible correction:
%
% Change line 5 so that the FEVAL function has one and only one input
% argument to pass to DoubleX.  If you want to double both 3 and 4 and
% obtain the vector [6, 8] then use this syntax:
%   SixEight = feval(DoubleX, [3, 4])
% If instead you just want the result 6 then use this:
%   SixEight = feval(DoubleX, 3)
% Finally, if you want to multiple 3 and 4 and return just the result 12,
% change the definition of DoubleX on line 3 to accept two input arguments
% and leave line 5 unchanged:
%   DoubleX = inline('x.*y','x','y');
% 
% On line 6, pass an input argument to DoubleX.  To create an empty array,
% simply pass an empty array to DoubleX:
%   Empty = feval(DoubleX, [])
%
% On line 12, if you want to call the ODE45 function with an inline function
% with an extra parameter, you need to specify that the inline function
% should accept that extra parameter.  Change line 10 to:
%   ODEFun = inline('-k*x', 't', 'x', 'k');