function testlasterror
% This function demonstrates the use of the LASTERR function

% This code tests the version of MATLAB you're using
try
    WhichVersion = version('-release');
catch
    % You're using a version of MATLAB older than MATLAB 6.0 (R12)
    % Setting version number to 0 so the check on line 27 returns false
    WhichVersion = '0';
end

disp('This function is designed to demonstrate the use of the LASTERR function in combination with TRY/CATCH.')

try
    disp('This display is from the DISP statement inside the TRY/CATCH block just before the error occurs.')
    x = [1 2 3]; % x is a 1 x 3 vector
    disp('The fourth element of the 1 x 3 vector x is:')
    disp(x(4)) % x(4) doesn't exist so this will throw an error
    disp('This code will only be executed if the previous line doesn''t error.')
catch
    disp(' ') % Adding a blank line to the output
    disp('Oops!  An error occurred.  The error message was:')
    disp(lasterr)
    disp(' ')
    
    if str2num(WhichVersion)>=13 % You're using MATLAB 6.5 (R13) or greater
        disp('You''re using a version of MATLAB that has the LASTERROR and RETHROW function available.')
        disp('Let''s test using these.')
        disp(' ')
        ErrorStructure = lasterror; % Create the error structure
        disp('The error message from LASTERROR was:')
        disp(ErrorStructure.message)
        disp('And the error identifier was:')
        disp(ErrorStructure.identifier)
        disp(' ')
        disp('If I understood why this error occurred and knew I could safely ignore it,')
        disp('I could check the identifier in the CATCH section of the TRY/CATCH block and proceed.')
        disp('However, in this example I want to exit and display the error message.')
        disp('Let''s exit the function at this point with an error using the RETHROW function.')
        rethrow(ErrorStructure)
    else
        disp('You''re using a version of MATLAB that does not have the LASTERROR or RETHROW functions.')
        disp('However, we can still use the ERROR function to exit this function.')
        error(lasterr)
    end
end

disp('If this line is displayed, MATLAB did not error on line 19.')
